@@ -17,6 +17,7 @@ def Shap_RFE_full(
     model,
     grid,
     cv_funct=RandomizedSearchCV,
+    cv_scoring="auto",
     n_iter=20,
     manage_groups=False,
     groups=None,
@@ -63,27 +64,26 @@ def Shap_RFE_full(
     """
     if groups is None:
         groups = pd.Series()
+        
+    if algo_type not in ["classification", "regression", "multiclass"]:
+        raise ValueError("algo_type argument must be one of ['classification', 'regression', 'multiclass']")  
+        
+    if (algo_type == "regression") and (str(cv_type.__class__()).startswith("StratifiedKFold")):
+            raise ValueError("Fold Cross Validation uncorrect for regression algorithm, use KFold() or GroupKFold()")
+            
+    if cv_scoring = "auto":
+        if algo_type == "classification":
+            cv_scoring="roc_auc"
+        elif algo_type == "regression":
+            cv_scoring="r2"
+        elif algo_type == "multiclass":
+            cv_scoring="balanced_accuracy"
 
     # Define the algo
-    if algo_type == "classification":
-        try:
-            CVSel_algo = cv_funct(model, grid, n_iter=n_iter, cv=cv_type, scoring="roc_auc")
-        except Exception:
-            CVSel_algo = cv_funct(model, grid, cv=cv_type, scoring="roc_auc")  # for GridSearchCV
-    elif algo_type == "regression":
-        if str(cv_type.__class__()).startswith("StratifiedKFold"):
-            raise ValueError("Fold Cross Validation uncorrect for regression algorithm, use KFold() or GroupKFold()")
-        try:
-            CVSel_algo = cv_funct(model, grid, n_iter=n_iter, cv=cv_type, scoring="r2")
-        except Exception:
-            CVSel_algo = cv_funct(model, grid, cv=cv_type, scoring="r2")  # for GridSearchCV
-    elif algo_type == "multiclass":
-        try:
-            CVSel_algo = cv_funct(model, grid, n_iter=n_iter, cv=cv_type, scoring="balanced_accuracy")
-        except Exception:
-            CVSel_algo = cv_funct(model, grid, cv=cv_type, scoring="balanced_accuracy")  # for GridSearchCV
-    else:
-        raise ValueError("algo_type argument must be one of ['classification', 'regression', 'multiclass']")
+    try:
+        CVSel_algo = cv_funct(model, grid, n_iter=n_iter, cv=cv_type, scoring=cv_scoring)
+    except Exception:
+        CVSel_algo = cv_funct(model, grid, cv=cv_type, scoring=cv_scoring)  # for GridSearchCV
 
     # Define the groups for Cross Validation
     if manage_groups:
